#!/usr/bin/env python3
"""Helper script to replay fixture output files."""

import sys
from pathlib import Path

if len(sys.argv) < 2:
    print(f"Usage: {sys.argv[0]} <output_file_path>", file=sys.stderr)
    sys.exit(1)

# 直接使用傳入的完整路徑
output_file = Path(sys.argv[1])

if output_file.exists():
    print(output_file.read_text(), end="")
else:
    print(f"Error: Output file not found: {output_file}", file=sys.stderr)
    sys.exit(1)
